import java.io.*; 
import javax.servlet.*; 

public class ParameterParser { 

	 private ServletRequest req; 

	 public ParameterParser(ServletRequest request) { 
		  this.req = request; 
	 } 

	 public String getStringParameter(String name) throws ParameterNotFoundException {
 
		  String value = req.getParameter(name);
		  if (value == null)
			   throw new ParameterNotFoundException(name + " not found");
		  else if (value.length() == 0)
			   throw new ParameterNotFoundException(name + " was empty");
		  else return value;
	 }

	 public String getStringParameter(String name, String def) { 
		  try { return getStringParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public boolean getBooleanParameter(String name) throws ParameterNotFoundException { 
		 return new Boolean(getStringParameter(name)).booleanValue(); 
	 } 

	 public boolean getBooleanParameter(String name, boolean def) { 
		  try { return getBooleanParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public byte getByteParameter(String name) 
		  throws ParameterNotFoundException, NumberFormatException { 
		  return Byte.parseByte(getStringParameter(name)); 
	 } 

	 public byte getByteParameter(String name, byte def) { 
		  try { return getByteParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public char getCharParameter(String name) throws ParameterNotFoundException { 
	 
		  String param = getStringParameter(name); 
		  if (param.length() == 0) 
			  throw new ParameterNotFoundException(name + " is empty string"); 
		  else 
			   return (param.charAt(0)); 
	 } 

	 public char getCharParameter(String name, char def) { 
		  try { return getCharParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public double getDoubleParameter(String name) 
		  throws ParameterNotFoundException, NumberFormatException { 
		  return new Double(getStringParameter(name)).doubleValue(); 
	 } 

	 public double getDoubleParameter(String name, double def) { 
		  try { return getDoubleParameter(name); } 
	  catch (Exception e) { return def; } 
	 } 

	 public float getFloatParameter(String name) 
		  throws ParameterNotFoundException, NumberFormatException { 
		  return new Float(getStringParameter(name)).floatValue(); 
	 } 

	 public float getFloatParameter(String name, float def) { 
		  try { return getFloatParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public int getIntParameter(String name) 
		  throws ParameterNotFoundException, NumberFormatException { 
		  return Integer.parseInt(getStringParameter(name)); 
	 } 

	 public int getIntParameter(String name, int def) { 
		  try { return getIntParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public long getLongParameter(String name) 
		  throws ParameterNotFoundException, NumberFormatException { 
		  return Long.parseLong(getStringParameter(name)); 
	 } 

	 public long getLongParameter(String name, long def) { 
		  try { return getLongParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 

	 public short getShortParameter(String name) 
		  throws ParameterNotFoundException, NumberFormatException { 
		  return Short.parseShort(getStringParameter(name)); 
	 } 

	 public short getShortParameter(String name, short def) { 
		  try { return getShortParameter(name); } 
		  catch (Exception e) { return def; } 
	 } 
}